import pieqt
class App():
	def __init__(self,argv=[]):
		self.app = QApplication(argv)
		self.window = QMainWindow()
		self.layout = QVBoxLayout()
		self.widget = QWidget()
	
	def setApp(self,app):
		self.app = app

	def setWindow(self,window):
		self.window = window

	def setLayout(self,layout):
		self.layout = layout
		self.widget.setLayout(self.layout)
		self.window.setCentralWidget(self.widget)

	def setWidget(self,widget):
		self.widget = widget

	def getApp(self):
		return self.app

	def getWindow(self):
		return self.window

	def getLayout(self):
		return self.layout

	def getWidget(self):
		return self.widget
	
	def run(self):
		self.window.show()
		self.app.exec_()
	
	def addWidget(self,widget):
		self.layout.addWidget(widget)
		self.setLayout(self.layout)
		



import PySide2
import PySide2.QtCore
from PySide2.QtGui import*
from PySide2.QtWidgets import*
import App

app = App()
QApplication = PySide2.QtWidgets.QApplication
QTextEdit = PySide2.QtWidgets.QTextEdit
QLabel = PySide2.QtWidgets.QLabel
QPushButton = PySide2.QtWidgets.QPushButton
QCheckBox = PySide2.QtWidgets.QCheckBox
QMainWindow = PySide2.QtWidgets.QMainWindow
QVBoxLayout = PySide2.QtWidgets.QVBoxLayout
QWidget = PySide2.QtWidgets.QWidget

def user_function():
	print("I am a user function")
callbacks = []
def run():
	global callbacks
	for callback in callbacks:
		callback()
def callback_user_functions():
	global callbacks
	for callback in callbacks:
		callback()
def add_function(function):
	global callbacks
	callbacks.append(function)
def main():
	print("Enter your code below!!!")
	global callbacks
	add_function(user_function)
	run()
	#callback_user_functions()

#if __name__ == "__main__":
#	main()



# -*- coding: utf-8 -*-

from setuptools import setup, find_packages


with open('README.md') as f:
    readme = f.read()

with open('LICENSE') as f:
    license = f.read()

setup(
    name='pieqt',
    version='0.0.4',
    description='simple description',
    long_description=readme,
    author='kostas_petsis',
    author_email='kostaspetsis@outlook.com',
    url='https://github.com/rivenblades/pieqt',
    license=license,
    py_modules={'App','pieqt'}
)
